@@ -150,10 +150,35 @@ void printtime(char *fmt, int time) {
 	
 	while (*c) {
 		switch (*c) {
+		case '\\':
+			c++;
+
+			switch (*c) {
+			case 0:
+				return;
+			case '\\':
+				printf("\\");
+				break;
+			case 'r':
+				printf("\r");
+				break;
+			case 'n':
+				printf("\n");
+				break;
+			case 't':
+				printf("\t");
+				break;
+			case '%':
+				printf("%%");
+				break;
+			}
+		    
+			break;
+		    
 		case '%':
 			strncpy(buf, c, 15);
 			for (i = 1; i < 100; i++) {
-				 if (buf[i] == 0) break;
+				 if (buf[i] == 0) return;
 				 if (buf[i] == 'd') break;
 				 if (buf[i] == 'h') break;
 				 if (buf[i] == 'm') break;
@@ -181,6 +206,8 @@ void printtime(char *fmt, int time) {
 			case 'n':
 				printf(buf, time);
 				break;
+			case 0:
+				return;
 			}
 			
 			c += i;
@@ -221,7 +248,6 @@ void showcount(int dtime, int ctype) {
 		printtime("\rTime Remaining: %d days, %02h:%02m:%02s.", dtime);
 		break;
 	case 2:
-		printf("\r");
 		printtime(custmessage, dtime);
 		break;
 	case 3:
@@ -294,7 +320,7 @@ int main(int argc, char **argv) {
 			break;
 		case 'V':
 			printf("delay - Version " VERSION "\n"
-			       "  Copyright (c) 1998-1999 Tom Rothamel\n"
+			       "  Copyright (c) 1998-2002 Tom Rothamel\n"
 			       "  This program has ABSOLUTELY NO WARRANTY. It can be distributed under\n"
 			       "  the terms of the GNU General Public License.\n"); 
 			exit(0);
